static char vis_copybox_doc[]="
Copy a rectangular area box within a visual.

Parameters: ()|(i,i,i,i)|(i,i,i,i,i,i) : the whole screen, the given area
                 in place, or the new area with the destination
Return:     None
";
static PyObject* vis_copybox(GGIVisualObject *self, PyObject *args) {
	int x,y,w,h,nx,ny;

	switch(PyTuple_GET_SIZE(args)) {
	case 0:
		if(ggiCopyBox(self->vis,0,0,self->mode.virt.x,self->mode.virt.y,0,0)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	case 4:
		if(!PyArg_ParseTuple(args, "iiii",&x,&y,&w,&h))
			return NULL;
		if(ggiCopyBox(self->vis,x,y,w,h,x,y)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	case 6:
		if(!PyArg_ParseTuple(args, "iiiiii",&x,&y,&w,&h,&nx,&ny))
			return NULL;
		if(ggiCopyBox(self->vis,x,y,w,h,nx,ny)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}

static char vis_crossblit_doc[]="
Copy a rectangular area box between two visuals.

Parameters: (O)|(O,i,i,i,i)|(O,i,i,i,i,i,i) : Same as copyarea() with the
            target visual as the destination.
Return:     None
";
static PyObject* vis_crossblit(GGIVisualObject*self, PyObject*args) {
	int x,y,w,h,nx,ny;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 1:
		if(!PyArg_ParseTuple(args, "O",&o))
			return NULL;
		if (GGIVisual_Check(o))
			PyErr_SetString(PyExc_TypeError,"Need a visual");
			return NULL;
		
		if(ggiCopyBox(self->vis,0,0,self->mode.virt.x,self->mode.virt.y,0,0)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	case 5:
		if(!PyArg_ParseTuple(args, "iiii",&x,&y,&w,&h))
			return NULL;
		if(ggiCopyBox(self->vis,x,y,w,h,x,y)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	case 7:
		if(!PyArg_ParseTuple(args, "iiiiii",&x,&y,&w,&h,&nx,&ny))
			return NULL;
		if(ggiCopyBox(self->vis,x,y,w,h,nx,ny)) {
			PyErr_SetString(PyExc_SystemError,"ggiCopyBox failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}

